@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """This module contains configuration variables.
 
 They may be set by your code as follows::
@@ -9,8 +7,6 @@ They may be set by your code as follows::
     config.VARIABLE = value
 """
 
-from __future__ import unicode_literals
-
 
 SOCO_CLASS = None
 """The class object to use when `SoCo` instances are created.
