@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 # pylint: disable=fixme, protected-access
 """The core module contains the SoCo class that implements
 the main entry to the SoCo functionality
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import datetime
 import logging
@@ -12,7 +10,6 @@ import re
 import socket
 from functools import wraps
 from xml.sax.saxutils import escape
-import xml.etree.ElementTree
 from xml.parsers.expat import ExpatError
 import warnings
 import xmltodict
@@ -22,7 +19,6 @@ from requests.exceptions import ConnectionError as RequestsConnectionError
 from requests.exceptions import ConnectTimeout, ReadTimeout
 
 from . import config
-from .compat import UnicodeType
 from .data_structures import (
     DidlObject,
     DidlPlaylistContainer,
@@ -33,7 +29,6 @@ from .data_structures import (
 from .cache import Cache
 from .data_structures_entry import from_didl_string
 from .exceptions import (
-    SoCoException,
     SoCoSlaveException,
     SoCoUPnPException,
     NotSupportedException,
@@ -96,14 +91,12 @@ class _ArgsSingleton(type):
         if key not in cls._instances:
             cls._instances[key] = {}
         if args not in cls._instances[key]:
-            cls._instances[key][args] = super(_ArgsSingleton, cls).__call__(
-                *args, **kwargs
-            )
+            cls._instances[key][args] = super().__call__(*args, **kwargs)
         return cls._instances[key][args]
 
 
 class _SocoSingletonBase(  # pylint: disable=too-few-public-methods,no-init
-    _ArgsSingleton(str("ArgsSingletonMeta"), (object,), {})
+    _ArgsSingleton("ArgsSingletonMeta", (object,), {})
 ):
 
     """The base class for the SoCo class.
@@ -122,7 +115,7 @@ def only_on_master(function):
         """Master checking inner function."""
         if not self.is_coordinator:
             message = (
-                'The method or property "{0}" can only be called/used '
+                'The method or property "{}" can only be called/used '
                 "on the coordinator in a group".format(function.__name__)
             )
             raise SoCoSlaveException(message)
@@ -150,16 +143,20 @@ class SoCo(_SocoSingletonBase):
         play_uri
         pause
         stop
+        end_direct_control_session
         seek
         next
         previous
         mute
         volume
         play_mode
+        shuffle
+        repeat
         cross_fade
         ramp_to_volume
         set_relative_volume
         get_current_track_info
+        get_current_media_info
         get_speaker_info
         get_current_transport_info
 
@@ -234,6 +231,7 @@ class SoCo(_SocoSingletonBase):
         is_playing_line_in
         switch_to_line_in
         switch_to_tv
+        available_actions
         set_sleep_timer
         get_sleep_timer
         create_stereo_pair
@@ -272,7 +270,7 @@ class SoCo(_SocoSingletonBase):
         # Sonos does not (yet) support IPv6
         try:
             socket.inet_aton(ip_address)
-        except socket.error as error:
+        except OSError as error:
             raise ValueError("Not a valid IP address string") from error
         #: The speaker's ip address
         self.ip_address = ip_address
@@ -309,10 +307,10 @@ class SoCo(_SocoSingletonBase):
         _LOG.debug("Created SoCo instance for ip: %s", ip_address)
 
     def __str__(self):
-        return "<{0} object at ip {1}>".format(self.__class__.__name__, self.ip_address)
+        return "<{} object at ip {}>".format(self.__class__.__name__, self.ip_address)
 
     def __repr__(self):
-        return '{0}("{1}")'.format(self.__class__.__name__, self.ip_address)
+        return '{}("{}")'.format(self.__class__.__name__, self.ip_address)
 
     @property
     def player_name(self):
@@ -458,6 +456,37 @@ class SoCo(_SocoSingletonBase):
 
         self.avTransport.SetPlayMode([("InstanceID", 0), ("NewPlayMode", playmode)])
 
+    @property
+    def shuffle(self):
+        """bool: The queue's shuffle option.
+
+        True if enabled, False otherwise.
+        """
+        return PLAY_MODES[self.play_mode][0]
+
+    @shuffle.setter
+    def shuffle(self, shuffle):
+        """Set the queue's shuffle option."""
+        repeat = self.repeat
+        self.play_mode = PLAY_MODE_BY_MEANING[(shuffle, repeat)]
+
+    @property
+    def repeat(self):
+        """bool: The queue's repeat option.
+
+        True if enabled, False otherwise.
+
+        Can also be the string ``'ONE'`` for play mode
+        ``'REPEAT_ONE'``.
+        """
+        return PLAY_MODES[self.play_mode][1]
+
+    @repeat.setter
+    def repeat(self, repeat):
+        """Set the queue's repeat option"""
+        shuffle = self.shuffle
+        self.play_mode = PLAY_MODE_BY_MEANING[(shuffle, repeat)]
+
     @property
     @only_on_master  # Only for symmetry with the setter
     def cross_fade(self):
@@ -573,7 +602,7 @@ class SoCo(_SocoSingletonBase):
             self.get_speaker_info()
 
         # first, set the queue itself as the source URI
-        uri = "x-rincon-queue:{0}#0".format(self.uid)
+        uri = "x-rincon-queue:{}#0".format(self.uid)
         self.avTransport.SetAVTransportURI(
             [("InstanceID", 0), ("CurrentURI", uri), ("CurrentURIMetaData", "")]
         )
@@ -669,7 +698,7 @@ class SoCo(_SocoSingletonBase):
         if force_radio:
             colon = uri.find(":")
             if colon > 0:
-                uri = "x-rincon-mp3radio{0}".format(uri[colon:])
+                uri = "x-rincon-mp3radio{}".format(uri[colon:])
 
         self.avTransport.SetAVTransportURI(
             [("InstanceID", 0), ("CurrentURI", uri), ("CurrentURIMetaData", meta)]
@@ -690,19 +719,60 @@ class SoCo(_SocoSingletonBase):
         self.avTransport.Stop([("InstanceID", 0), ("Speed", 1)])
 
     @only_on_master
-    def seek(self, timestamp):
-        """Seek to a given timestamp in the current track, specified in the
-        format of HH:MM:SS or H:MM:SS.
+    def end_direct_control_session(self):
+        """Ends all third-party controlled streaming sessions."""
+        self.avTransport.EndDirectControlSession([("InstanceID", 0)])
+
+    @only_on_master
+    def seek(self, position=None, track=None):
+        """Seek to a given position.
+
+        You can seek both a relative position in the current track and a track
+        number in the queue.
+        It is even possible to seek to a tuple or dict containing the absolute
+        position (relative pos. and track nr.)::
+
+            t = ('0:00:00', 0)
+            player.seek(*t)
+            d = {'position': '0:00:00', 'track': 0}
+            player.seek(**d)
+
+        Args:
+            position (str): The desired timestamp in the current track,
+                specified in the format of HH:MM:SS or H:MM:SS
+            track (int): The (zero-based) track index in the queue
 
         Raises:
-            ValueError: if the given timestamp is invalid.
-        """
-        if not re.match(r"^[0-9][0-9]?:[0-9][0-9]:[0-9][0-9]$", timestamp):
-            raise ValueError("invalid timestamp, use HH:MM:SS format")
+            ValueError: If neither position nor track are specified.
+            SoCoUPnPException: UPnP Error 701 if seeking is not supported,
+                UPnP Error 711 if the target is invalid.
 
-        self.avTransport.Seek(
-            [("InstanceID", 0), ("Unit", "REL_TIME"), ("Target", timestamp)]
-        )
+        Note:
+            The 'track' parameter can only be used if the queue is currently
+            playing. If not, use :py:meth:`play_from_queue`.
+
+        This is currently faster than :py:meth:`play_from_queue` if already
+        using the queue, as it does not reinstate the queue.
+
+        If speaker is already playing it will continue to play after
+        seek. If paused it will remain paused.
+        """
+
+        if track is None and position is None:
+            raise ValueError("No position or track information given")
+
+        if track is not None:
+            self.avTransport.Seek(
+                [("InstanceID", 0), ("Unit", "TRACK_NR"), ("Target", track + 1)]
+            )
+
+        if position is not None:
+            if not re.match(r"^[0-9][0-9]?:[0-9][0-9]:[0-9][0-9]$", position):
+                raise ValueError("invalid timestamp, use HH:MM:SS format")
+
+            self.avTransport.Seek(
+                [("InstanceID", 0), ("Unit", "REL_TIME"), ("Target", position)]
+            )
 
     @only_on_master
     def next(self):
@@ -1054,13 +1124,6 @@ class SoCo(_SocoSingletonBase):
             raise NotSupportedException from error
 
     def _parse_zone_group_state(self):
-        """Parse zone group state, catching some exceptions."""
-        try:
-            self.__parse_zone_group_state_wrapped()
-        except xml.etree.ElementTree.ParseError as ex:
-            raise SoCoException("Parse error: " + str(ex)) from ex
-
-    def __parse_zone_group_state_wrapped(self):
         """The Zone Group State contains a lot of useful information.
 
         Retrieve and parse it, and populate the relevant properties.
@@ -1147,12 +1210,8 @@ class SoCo(_SocoSingletonBase):
         # and the set of all members
         self._all_zones.clear()
         self._visible_zones.clear()
-        # The response is wrapped in ZoneGroups from Sonos 10.1
-        zonegroups = tree.find("ZoneGroups")
-        if zonegroups is not None:
-            tree = zonegroups
         # Loop over each ZoneGroup Element
-        for group_element in tree.findall("ZoneGroup"):
+        for group_element in tree.find("ZoneGroups").findall("ZoneGroup"):
             coordinator_uid = group_element.attrib["Coordinator"]
             group_uid = group_element.attrib["ID"]
             group_coordinator = None
@@ -1251,7 +1310,7 @@ class SoCo(_SocoSingletonBase):
         self.avTransport.SetAVTransportURI(
             [
                 ("InstanceID", 0),
-                ("CurrentURI", "x-rincon:{0}".format(master.uid)),
+                ("CurrentURI", "x-rincon:{}".format(master.uid)),
                 ("CurrentURIMetaData", ""),
             ]
         )
@@ -1319,7 +1378,7 @@ class SoCo(_SocoSingletonBase):
         self.avTransport.SetAVTransportURI(
             [
                 ("InstanceID", 0),
-                ("CurrentURI", "x-rincon-stream:{0}".format(uid)),
+                ("CurrentURI", "x-rincon-stream:{}".format(uid)),
                 ("CurrentURIMetaData", ""),
             ]
         )
@@ -1386,7 +1445,7 @@ class SoCo(_SocoSingletonBase):
         self.avTransport.SetAVTransportURI(
             [
                 ("InstanceID", 0),
-                ("CurrentURI", "x-sonos-htastream:{0}:spdif".format(self.uid)),
+                ("CurrentURI", "x-sonos-htastream:{}:spdif".format(self.uid)),
                 ("CurrentURIMetaData", ""),
             ]
         )
@@ -1448,7 +1507,6 @@ class SoCo(_SocoSingletonBase):
             ]
         )
 
-    # pylint: disable=too-many-branches
     def get_current_track_info(self):
         """Get information about the currently playing track.
 
@@ -1488,10 +1546,10 @@ class SoCo(_SocoSingletonBase):
         # Store the entire Metadata entry in the track, this can then be
         # used if needed by the client to restart a given URI
         track["metadata"] = metadata
-        # Duration seems to be '0:00:00' when listening to radio
-        if metadata != "" and track["duration"] == "0:00:00":
-            metadata = XML.fromstring(really_utf8(metadata))
-            # Try parse trackinfo
+
+        def _parse_radio_metadata(metadata):
+            """Try to parse trackinfo from radio metadata."""
+            radio_track = {}
             trackinfo = (
                 metadata.findtext(
                     ".//{urn:schemas-rinconnetworks-com:" "metadata-1-0/}streamContent"
@@ -1501,9 +1559,9 @@ class SoCo(_SocoSingletonBase):
             index = trackinfo.find(" - ")
 
             if index > -1:
-                track["artist"] = trackinfo[:index]
-                track["title"] = trackinfo[index + 3 :]
-            elif re.match(r"(BR P\|)?TYPE=SNG\|.*", trackinfo):
+                radio_track["artist"] = trackinfo[:index]
+                radio_track["title"] = trackinfo[index + 3 :]
+            elif "TYPE=SNG|" in trackinfo:
                 # Examples from services:
                 #  Apple Music radio:
                 #   "TYPE=SNG|TITLE Couleurs|ARTIST M83|ALBUM Saturdays = Youth"
@@ -1511,18 +1569,25 @@ class SoCo(_SocoSingletonBase):
                 #   "BR P|TYPE=SNG|TITLE 7.15.17 LA|ARTIST Eagles|ALBUM "
                 tags = dict([p.split(" ", 1) for p in trackinfo.split("|") if " " in p])
                 if tags.get("TITLE"):
-                    track["title"] = tags["TITLE"]
+                    radio_track["title"] = tags["TITLE"]
                 if tags.get("ARTIST"):
-                    track["artist"] = tags["ARTIST"]
+                    radio_track["artist"] = tags["ARTIST"]
                 if tags.get("ALBUM"):
-                    track["album"] = tags["ALBUM"]
+                    radio_track["album"] = tags["ALBUM"]
             else:
                 # Might find some kind of title anyway in metadata
-                track["title"] = metadata.findtext(
+                radio_track["title"] = metadata.findtext(
                     ".//{http://purl.org/dc/" "elements/1.1/}title"
                 )
-                if not track["title"]:
-                    track["title"] = trackinfo
+                if not radio_track["title"]:
+                    radio_track["title"] = trackinfo
+
+            return radio_track
+
+        # Duration seems to be '0:00:00' when listening to radio
+        if metadata != "" and track["duration"] == "0:00:00":
+            metadata = XML.fromstring(really_utf8(metadata))
+            track.update(_parse_radio_metadata(metadata))
 
         # If the speaker is playing from the line-in source, querying for track
         # metadata will return "NOT_IMPLEMENTED".
@@ -1564,6 +1629,8 @@ class SoCo(_SocoSingletonBase):
             dict: A dictionary containing information about the currently
             playing media: uri, channel.
 
+        If we're unable to return data for a field, we'll return an empty
+        string.
         """
         response = self.avTransport.GetMediaInfo([("InstanceID", 0)])
         media = {"uri": "", "channel": ""}
@@ -1676,6 +1743,24 @@ class SoCo(_SocoSingletonBase):
 
         return playstate
 
+    @property
+    @only_on_master
+    def available_actions(self):
+        """The transport actions that are currently available on the
+        speaker.
+
+        :returns: list: A list of strings representing the available actions, such as
+                    ['Set', 'Stop', 'Play'].
+
+        Possible list items are: 'Set', 'Stop', 'Pause', 'Play',
+        'Next', 'Previous', 'SeekTime', 'SeekTrackNr'.
+        """
+        result = self.avTransport.GetCurrentTransportActions([("InstanceID", 0)])
+        actions = result["Actions"]
+        # The actions might look like 'X_DLNA_SeekTime', but we only want the
+        # last part
+        return [action.split("_")[-1] for action in actions.split(", ")]
+
     def get_queue(self, start=0, max_items=100, full_album_art_uri=False):
         """Get information about the queue.
 
@@ -1685,7 +1770,7 @@ class SoCo(_SocoSingletonBase):
             IP address
         :returns: A :py:class:`~.soco.data_structures.Queue` object
 
-        This method is heavly based on Sam Soffes (aka soffes) ruby
+        This method is heavily based on Sam Soffes (aka soffes) ruby
         implementation
         """
         queue = []
@@ -1767,217 +1852,6 @@ class SoCo(_SocoSingletonBase):
         item = DidlObject(resources=res, title="", parent_id="", item_id="")
         return self.add_to_queue(item, position, as_next)
 
-    @staticmethod
-    def _spotify_uri(uri):
-        """str: The canonical Spotify URI."""
-        match = re.search(r"spotify.*[:/](album|track|playlist)[:/](\w+)", uri)
-        if match:
-            return "spotify:" + match.group(1) + ":" + match.group(2)
-
-        return None
-
-    @staticmethod
-    def _tidal_uri(uri):
-        """str: The canonical Tidal URI."""
-        match = re.search(r"https://tidal.*[:/](album|track|playlist)[:/]([\w-]+)", uri)
-        if match:
-            return "tidal:" + match.group(1) + ":" + match.group(2)
-
-        return None
-
-    def is_spotify_uri(self, uri):
-        """bool: Is the URI for Spotify."""
-        return self._spotify_uri(uri) is not None
-
-    def is_tidal_uri(self, uri):
-        """bool: Is the URI for Tidal."""
-        return self._tidal_uri(uri) is not None
-
-    def is_service_uri(self, uri):
-        """bool: Is the URI for a music service."""
-        return self.is_spotify_uri(uri) or self.is_tidal_uri(uri)
-
-    @only_on_master
-    def add_spotify_uri_to_queue(self, uri, position=0, as_next=False):
-        """Add a Spotify item to the queue.
-
-        Args:
-            uri (str): A URI like `spotify:album:6wiUBliPe76YAVpNEdidpY`.
-            position (int): The index (1-based) at which the URI should be
-                added. Default is 0 (add URI at the end of the queue).
-            as_next (bool): Whether this URI should be played as the next
-                track in shuffle mode. This only works if `play_mode=SHUFFLE`.
-
-        Returns:
-            int: The index of the new item in the queue.
-        """
-
-        spotify_services = (
-            2311,  # Global
-            3079,  # US
-        )
-
-        for service_no in spotify_services:
-            try:
-                return self._add_spotify_uri_to_queue_with_service(
-                    uri, service_no, position, as_next
-                )
-            except SoCoUPnPException as err:
-                exception = err
-                if err.error_code != "800":
-                    break
-
-        raise exception
-
-    @only_on_master
-    def _add_spotify_uri_to_queue_with_service(
-        self, uri, service_no, position=0, as_next=False
-    ):
-        """Helper for add_spotify_uri_to_queue."""
-
-        spotify_uri = self._spotify_uri(uri)
-
-        spotify_magic = {
-            "album": {
-                "prefix": "x-rincon-cpcontainer:1004206c",
-                "key": "1004206c",
-                "class": "object.container.album.musicAlbum",
-            },
-            "track": {
-                "prefix": "",
-                "key": "00032020",
-                "class": "object.item.audioItem.musicTrack",
-            },
-            "playlist": {
-                "prefix": "x-rincon-cpcontainer:1006206c",
-                "key": "1006206c",
-                "class": "object.container.playlistContainer",
-            },
-        }
-        spotify_type = spotify_uri.split(":")[1]
-
-        encoded_uri = spotify_uri.replace(":", "%3a")
-        enqueue_uri = spotify_magic[spotify_type]["prefix"] + encoded_uri
-
-        metadata_template = (
-            '<DIDL-Lite xmlns:dc="http://purl.org/dc/elements'
-            '/1.1/" xmlns:upnp="urn:schemas-upnp-org:metadata'
-            '-1-0/upnp/" xmlns:r="urn:schemas-rinconnetworks-'
-            'com:metadata-1-0/" xmlns="urn:schemas-upnp-org:m'
-            'etadata-1-0/DIDL-Lite/"><item id="{item_id}" res'
-            'tricted="true"><upnp:class>{item_class}</upnp:cl'
-            'ass><desc id="cdudn" nameSpace="urn:schemas-rinc'
-            'onnetworks-com:metadata-1-0/">SA_RINCON{sn}_X_#S'
-            "vc{sn}-0-Token</desc></item></DIDL-Lite>"
-        )
-
-        metadata = metadata_template.format(
-            item_id=spotify_magic[spotify_type]["key"] + encoded_uri,
-            item_class=spotify_magic[spotify_type]["class"],
-            sn=service_no,
-        )
-
-        response = self.avTransport.AddURIToQueue(
-            [
-                ("InstanceID", 0),
-                ("EnqueuedURI", enqueue_uri),
-                ("EnqueuedURIMetaData", metadata),
-                ("DesiredFirstTrackNumberEnqueued", position),
-                ("EnqueueAsNext", int(as_next)),
-            ]
-        )
-        qnumber = response["FirstTrackNumberEnqueued"]
-        return int(qnumber)
-
-    @only_on_master
-    def add_tidal_uri_to_queue(self, uri, position=0, as_next=False):
-        """Add a queueable item to the queue.
-
-        Args:
-            uri (str): A URI like `https://tidal.com/browse/album/157273956`.
-            position (int): The index (1-based) at which the URI should be
-                added. Default is 0 (add URI at the end of the queue).
-            as_next (bool): Whether this URI should be played as the next
-                track in shuffle mode. This only works if `play_mode=SHUFFLE`.
-
-        Returns:
-            int: The index of the new item in the queue.
-        """
-
-        tidal_uri = self._tidal_uri(uri)
-
-        tidal_magic = {
-            "album": {
-                "prefix": "x-rincon-cpcontainer:1004206c",
-                "key": "00040000",
-                "class": "object.container.album.musicAlbum",
-            },
-            "track": {
-                "prefix": "",
-                "key": "00032020",
-                "class": "object.item.audioItem.musicTrack",
-            },
-            "playlist": {
-                "prefix": "x-rincon-cpcontainer:1006206c",
-                "key": "1006206c",
-                "class": "object.container.playlistContainer",
-            },
-        }
-        tidal_type = tidal_uri.split(":")[1]
-
-        encoded_uri = tidal_uri.replace("tidal:", "").replace(":", "%2f")
-        enqueue_uri = tidal_magic[tidal_type]["prefix"] + encoded_uri
-
-        metadata_template = (
-            '<DIDL-Lite xmlns:dc="http://purl.org/dc/elements'
-            '/1.1/" xmlns:upnp="urn:schemas-upnp-org:metadata'
-            '-1-0/upnp/" xmlns:r="urn:schemas-rinconnetworks-'
-            'com:metadata-1-0/" xmlns="urn:schemas-upnp-org:m'
-            'etadata-1-0/DIDL-Lite/"><item id="{item_id}" res'
-            'tricted="true"><upnp:class>{item_class}</upnp:cl'
-            'ass><desc id="cdudn" nameSpace="urn:schemas-rinc'
-            'onnetworks-com:metadata-1-0/">SA_RINCON44551_X_#'
-            "Svc33551-0-Token</desc></item></DIDL-Lite>"
-        )
-
-        metadata = metadata_template.format(
-            item_id=tidal_magic[tidal_type]["key"] + encoded_uri,
-            item_class=tidal_magic[tidal_type]["class"],
-        )
-
-        response = self.avTransport.AddURIToQueue(
-            [
-                ("InstanceID", 0),
-                ("EnqueuedURI", enqueue_uri),
-                ("EnqueuedURIMetaData", metadata),
-                ("DesiredFirstTrackNumberEnqueued", position),
-                ("EnqueueAsNext", int(as_next)),
-            ]
-        )
-        qnumber = response["FirstTrackNumberEnqueued"]
-        return int(qnumber)
-
-    @only_on_master
-    def add_service_uri_to_queue(self, uri, position=0, as_next=False):
-        """Add a Spotify/Tidal/... item to the queue.
-
-        Args:
-            uri (str): A URI like `spotify:album:6wiUBliPe76YAVpNEdidpY`.
-            position (int): The index (1-based) at which the URI should be
-                added. Default is 0 (add URI at the end of the queue).
-            as_next (bool): Whether this URI should be played as the next
-                track in shuffle mode. This only works if `play_mode=SHUFFLE`.
-
-        Returns:
-            int: The index of the new item in the queue.
-        """
-        if self.is_spotify_uri(uri):
-            return self.add_spotify_uri_to_queue(uri, position, as_next)
-        elif self.is_tidal_uri(uri):
-            return self.add_tidal_uri_to_queue(uri, position, as_next)
-
-        raise SoCoException("Unsupported URI: " + uri)
-
     @only_on_master
     def add_to_queue(self, queueable_item, position=0, as_next=False):
         """Add a queueable item to the queue.
@@ -2137,7 +2011,7 @@ class SoCo(_SocoSingletonBase):
                     "ObjectID",
                     "FV:2"
                     if favorite_type is SONOS_FAVORITES
-                    else "R:0/{0}".format(favorite_type),
+                    else "R:0/{}".format(favorite_type),
                 ),
                 ("BrowseFlag", "BrowseDirectChildren"),
                 ("Filter", "*"),
@@ -2197,7 +2071,7 @@ class SoCo(_SocoSingletonBase):
 
         item_id = response["AssignedObjectID"]
         obj_id = item_id.split(":", 2)[1]
-        uri = "file:///jffs/settings/savedqueues.rsq#{0}".format(obj_id)
+        uri = "file:///jffs/settings/savedqueues.rsq#{}".format(obj_id)
 
         res = [DidlResource(uri=uri, protocol_info="x-rincon-playlist:*:*:*")]
         return DidlPlaylistContainer(
@@ -2222,7 +2096,7 @@ class SoCo(_SocoSingletonBase):
         )
         item_id = response["AssignedObjectID"]
         obj_id = item_id.split(":", 2)[1]
-        uri = "file:///jffs/settings/savedqueues.rsq#{0}".format(obj_id)
+        uri = "file:///jffs/settings/savedqueues.rsq#{}".format(obj_id)
         res = [DidlResource(uri=uri, protocol_info="x-rincon-playlist:*:*:*")]
         return DidlPlaylistContainer(
             resources=res, title=title, parent_id="SQ:", item_id=item_id
@@ -2420,7 +2294,7 @@ class SoCo(_SocoSingletonBase):
         # allow either a string 'SQ:10' or an object with item_id attribute.
         object_id = getattr(sonos_playlist, "item_id", sonos_playlist)
 
-        if isinstance(tracks, UnicodeType):
+        if isinstance(tracks, str):
             track_list = [
                 tracks,
             ]
@@ -2583,7 +2457,7 @@ class SoCo(_SocoSingletonBase):
         for sonos_playlist in self.get_sonos_playlists():
             if getattr(sonos_playlist, attr_name) == match:
                 return sonos_playlist
-        raise ValueError('No match on "{0}" for value "{1}"'.format(attr_name, match))
+        raise ValueError('No match on "{}" for value "{}"'.format(attr_name, match))
 
     def get_battery_info(self, timeout=3.0):
         """Get battery information for a Sonos speaker.
@@ -2700,6 +2574,5 @@ SOURCES = {
 # Soundbar product names
 SOUNDBARS = ("playbase", "playbar", "beam", "sonos amp", "arc", "arc sl")
 
-
 if config.SOCO_CLASS is None:
     config.SOCO_CLASS = SoCo
