@@ -229,7 +229,7 @@ class EventListener(EventListenerBase):
         self._listener_thread.join(1)
         # check if join timed out and issue a warning if it did
         if self._listener_thread.is_alive():
-            log.debug("Event Listener did not shutdown gracefully.")
+            log.warning("Event Listener did not shutdown gracefully.")
 
 
 class Subscription(SubscriptionBase):
