@@ -248,7 +248,7 @@ class EventListener(EventListenerBase):  # pylint: disable=too-many-instance-att
                 break
             # pylint: disable=invalid-name
             except socket.error as e:
-                log.debug(e)
+                log.warning(e)
                 continue
 
         if not self.port:
