@@ -100,10 +100,7 @@ def parse_event_xml(xml_event):
                         # Wrap any parsing exception in a SoCoFault, so the
                         # user can handle it
                         try:
-                            didl = from_didl_string(value)
-                            if not didl:
-                                continue
-                            value = didl[0]
+                            value = from_didl_string(value)[0]
                         except SoCoException as original_exception:
                             log.debug(
                                 "Event contains illegal metadata"
@@ -247,7 +244,7 @@ class EventNotifyHandlerBase:
             # Pass the event on for handling
             subscription.send_event(event)
         else:
-            log.debug("No service registered for %s", sid)
+            log.info("No service registered for %s", sid)
 
     # pylint: disable=missing-docstring
     def log_event(self, seq, service_id, timestamp):
@@ -601,7 +598,7 @@ class SubscriptionBase:
                 self.events.put(event)
             # pylint: disable=broad-except
             except Exception as ex:
-                log.debug("Error putting event %s, ex=%s", event, ex)
+                log.warning("Error putting event %s, ex=%s", event, ex)
 
     # pylint: disable=missing-docstring
     def _auto_renew_start(self, interval):
@@ -662,7 +659,7 @@ class SubscriptionBase:
         # Cancel any auto renew
         self._auto_renew_cancel()
         if msg:
-            log.debug(msg)
+            log.info(msg)
 
     @property
     def time_left(self):
