@@ -319,7 +319,7 @@ class TestGetCurrentTrackInfo:
     )
 
     def test_get(self, soco):
-        """Test is the return value is a dictinary and contains the following
+        """Test that the return value is a dictionary and contains the following
         keys: album, artist, title, uri, playlist_position, duration,
         album_art and position.
         """
@@ -328,6 +328,25 @@ class TestGetCurrentTrackInfo:
         assert sorted(info.keys()) == self.info_keys
 
 
+class TestGetCurrentMediaInfo:
+    """Integration test for the get_current_media_info method."""
+
+    info_keys = sorted(
+        [
+            "uri",
+            "channel",
+        ]
+    )
+
+    def test_get(self, soco):
+        """Test that the return value is a dictionary and contains the expected
+        keys.
+        """
+        info = soco.get_current_media_info()
+        assert isinstance(info, dict)
+        assert sorted(info.keys()) == self.info_keys
+
+
 class TestGetSpeakerInfo:
     """Integration test for the get_speaker_info method."""
 
