@@ -1,17 +1,9 @@
-# -*- coding: utf-8 -*-
 """Tests for the soap module."""
 
-from __future__ import unicode_literals
 
 from pysonos.soap import SoapMessage
 from pysonos.xml import XML
-
-try:
-    # New in Python 3.3
-    from unittest import mock
-except ImportError:
-    # Python 2.7
-    import mock
+from unittest import mock
 
 
 DUMMY_VALID_RESPONSE = "".join(
